module TungstenEngine
  module Core
    # Represents the span between two points in time
    class TimeSpan
      attr_accessor :milliseconds

      def self.from_microseconds(microseconds)
        TimeSpan.from_milliseconds(microseconds / 1000.0)
      end

      def self.from_milliseconds(milliseconds)
        me = TimeSpan.new
        me.milliseconds = milliseconds
        return me
      end

      def self.from_seconds(seconds)
        TimeSpan.from_milliseconds(seconds * 1000)
      end

      def self.from_minutes(minutes)
        TimeSpan.from_milliseconds(minutes * 60000)
      end

      def self.from_hours(hours)
        TimeSpan.from_milliseconds(hours * 3600000)
      end

      def self.from_days(days)
        TimeSpan.from_milliseconds(days * 86400000)
      end

      def self.from_years(years)
        TimeSpan.from_days(years * 365.242)
      end

      def self.diff(start_date_time, end_date_time)
        TimeSpan.from_seconds(end_date_time - start_date_time)
      end

      def microseconds
        milliseconds * 1000
      end

      def seconds
        milliseconds * 0.001
      end

      def minutes
        seconds * 0.0166667
      end

      def hours
        minutes * 0.0166667
      end

      def days
        hours * 0.0416667
      end

      def years
        days * 0.00273791
      end
    end
  end
end